import { Construct } from 'constructs';
export declare enum PriceClass {
    /**
       * USA, Canada, Europe, & Israel.
       *
       * @stability stable
       */
    PRICE_CLASS_100 = "PriceClass_100",
    /**
       * PRICE_CLASS_100 + South Africa, Kenya, Middle East, Japan, Singapore, South Korea, Taiwan, Hong Kong, & Philippines.
       *
       * @stability stable
       */
    PRICE_CLASS_200 = "PriceClass_200",
    /**
       * All locations.
       *
       * @stability stable
       */
    PRICE_CLASS_ALL = "PriceClass_All"
}
export interface BasicSiteConfiguration {
    /**
     * Local path to the website folder you want to deploy on S3.
     */
    readonly websiteFolder: string;
    /**
     * The index document of the website.
     */
    readonly indexDoc: string;
    /**
     * The error document of the website.
     * @default - No error document.
     */
    readonly errorDoc?: string;
    /**
     * Hosted Zone used to create the DNS record for the website.
     */
    readonly hostedZone: string;
}
export interface CloudfrontSiteConfiguration {
    /**
     * Local path to the website folder you want to deploy on S3.
     */
    readonly websiteFolder: string;
    /**
     * The index document of the website.
     */
    readonly indexDoc: string;
    /**
     * The error document of the website.
     * @default - No error document.
     */
    readonly errorDoc?: string;
    /**
     * Hosted Zone used to create the DNS record for the website.
     */
    readonly hostedZone: string;
    /**
     * Used to deploy a Cloudfront site with a single domain. e.g. sample.example.com
     * If you include a value for both domain and subDomain,
     * an error will be thrown.
     *
     * @default - no value
     */
    readonly domain?: string;
    /**
     * The sub-domain name you want to deploy. e.g. www.example.com
     * If you include a value for both domain and subDomain,
     * an error will be thrown.
     *
     * @default - no value
     */
    readonly subDomain?: string;
    /**
     * The price class determines how many edge locations CloudFront will use for your distribution.
     * @default PriceClass.PRICE_CLASS_100.
     * @see https://aws.amazon.com/cloudfront/pricing/.
     */
    readonly priceClass?: PriceClass;
}
export declare class CreateBasicSite extends Construct {
    constructor(scope: Construct, id: string, props: BasicSiteConfiguration);
}
export declare class CreateCloudfrontSite extends Construct {
    constructor(scope: Construct, id: string, props: CloudfrontSiteConfiguration);
}
